diff --git a/main/ui/src/main/java/org/cryptomator/ui/mainwindow/MainWindowTitleController.java b/main/ui/src/main/java/org/cryptomator/ui/mainwindow/MainWindowTitleController.java
index 5a5bb59a6..ea9311c88 100644
--- a/main/ui/src/main/java/org/cryptomator/ui/mainwindow/MainWindowTitleController.java
+++ b/main/ui/src/main/java/org/cryptomator/ui/mainwindow/MainWindowTitleController.java
@@ -95,7 +95,7 @@ public class MainWindowTitleController implements FxController {
@FXML
public void showDonationKeyPreferences() {
- application.showPreferencesWindow(SelectedPreferencesTab.DONATION_KEY);
+ application.showPreferencesWindow(SelectedPreferencesTab.CONTRIBUTE);
}
/* Getter/Setter */
diff --git a/main/ui/src/main/java/org/cryptomator/ui/preferences/GeneralPreferencesController.java b/main/ui/src/main/java/org/cryptomator/ui/preferences/GeneralPreferencesController.java
index ea1fbfe3a..64d71a8b7 100644
--- a/main/ui/src/main/java/org/cryptomator/ui/preferences/GeneralPreferencesController.java
+++ b/main/ui/src/main/java/org/cryptomator/ui/preferences/GeneralPreferencesController.java
@@ -157,8 +157,8 @@ public class GeneralPreferencesController implements FxController {
@FXML
- public void showDonationTab() {
- selectedTabProperty.set(SelectedPreferencesTab.DONATION_KEY);
+ public void showContributeTab() {
+ selectedTabProperty.set(SelectedPreferencesTab.CONTRIBUTE);
}
@FXML
diff --git a/main/ui/src/main/java/org/cryptomator/ui/preferences/PreferencesController.java b/main/ui/src/main/java/org/cryptomator/ui/preferences/PreferencesController.java
index 64d5c991b..276794753 100644
--- a/main/ui/src/main/java/org/cryptomator/ui/preferences/PreferencesController.java
+++ b/main/ui/src/main/java/org/cryptomator/ui/preferences/PreferencesController.java
@@ -26,7 +26,7 @@ public class PreferencesController implements FxController {
public Tab generalTab;
public Tab volumeTab;
public Tab updatesTab;
- public Tab donationKeyTab;
+ public Tab contributeTab;
public Tab aboutTab;
@Inject
@@ -52,7 +52,7 @@ public class PreferencesController implements FxController {
return switch (selectedTab) {
case UPDATES -> updatesTab;
case VOLUME -> volumeTab;
- case DONATION_KEY -> donationKeyTab;
+ case CONTRIBUTE -> contributeTab;
case GENERAL -> generalTab;
case ABOUT -> aboutTab;
case ANY -> updateAvailable.get() ? updatesTab : generalTab;
diff --git a/main/ui/src/main/java/org/cryptomator/ui/preferences/PreferencesModule.java b/main/ui/src/main/java/org/cryptomator/ui/preferences/PreferencesModule.java
index 51fa6b581..5fee567b7 100644
--- a/main/ui/src/main/java/org/cryptomator/ui/preferences/PreferencesModule.java
+++ b/main/ui/src/main/java/org/cryptomator/ui/preferences/PreferencesModule.java
@@ -77,8 +77,8 @@ abstract class PreferencesModule {
@Binds
@IntoMap
- @FxControllerKey(DonationKeyPreferencesController.class)
- abstract FxController bindDonationKeyPreferencesController(DonationKeyPreferencesController controller);
+ @FxControllerKey(SupporterCertificateController.class)
+ abstract FxController bindSupporterCertificatePreferencesController(SupporterCertificateController controller);
@Binds
@IntoMap
diff --git a/main/ui/src/main/java/org/cryptomator/ui/preferences/DonationKeyPreferencesController.java b/main/ui/src/main/java/org/cryptomator/ui/preferences/SupporterCertificateController.java
similarity index 68%
rename from main/ui/src/main/java/org/cryptomator/ui/preferences/DonationKeyPreferencesController.java
rename to main/ui/src/main/java/org/cryptomator/ui/preferences/SupporterCertificateController.java
index a4814ec82..02b8bab91 100644
--- a/main/ui/src/main/java/org/cryptomator/ui/preferences/DonationKeyPreferencesController.java
+++ b/main/ui/src/main/java/org/cryptomator/ui/preferences/SupporterCertificateController.java
@@ -14,17 +14,17 @@ import javafx.scene.control.TextArea;
import javafx.scene.control.TextFormatter;
@PreferencesScoped
-public class DonationKeyPreferencesController implements FxController {
+public class SupporterCertificateController implements FxController {
- private static final String DONATION_URI = "https://store.cryptomator.org/desktop";
+ private static final String SUPPORTER_URI = "https://store.cryptomator.org/desktop";
private final Application application;
private final LicenseHolder licenseHolder;
private final Settings settings;
- public TextArea donationKeyField;
+ public TextArea supporterCertificateField;
@Inject
- DonationKeyPreferencesController(Application application, LicenseHolder licenseHolder, Settings settings) {
+ SupporterCertificateController(Application application, LicenseHolder licenseHolder, Settings settings) {
this.application = application;
this.licenseHolder = licenseHolder;
this.settings = settings;
@@ -32,9 +32,9 @@ public class DonationKeyPreferencesController implements FxController {
@FXML
public void initialize() {
- donationKeyField.setText(licenseHolder.getLicenseKey().orElse(null));
- donationKeyField.textProperty().addListener(this::registrationKeyChanged);
- donationKeyField.setTextFormatter(new TextFormatter<>(this::checkVaultNameLength));
+ supporterCertificateField.setText(licenseHolder.getLicenseKey().orElse(null));
+ supporterCertificateField.textProperty().addListener(this::registrationKeyChanged);
+ supporterCertificateField.setTextFormatter(new TextFormatter<>(this::checkVaultNameLength));
}
private TextFormatter.Change checkVaultNameLength(TextFormatter.Change change) {
@@ -53,8 +53,8 @@ public class DonationKeyPreferencesController implements FxController {
}
@FXML
- public void getDonationKey() {
- application.getHostServices().showDocument(DONATION_URI);
+ public void getSupporterCertificate() {
+ application.getHostServices().showDocument(SUPPORTER_URI);
}
public LicenseHolder getLicenseHolder() {
diff --git a/main/ui/src/main/resources/fxml/preferences.fxml b/main/ui/src/main/resources/fxml/preferences.fxml
index c0cd2b6c7..643b31176 100644
--- a/main/ui/src/main/resources/fxml/preferences.fxml
+++ b/main/ui/src/main/resources/fxml/preferences.fxml
@@ -38,12 +38,12 @@
-
+
-
+
diff --git a/main/ui/src/main/resources/fxml/preferences_donationkey.fxml b/main/ui/src/main/resources/fxml/preferences_contribute.fxml
similarity index 72%
rename from main/ui/src/main/resources/fxml/preferences_donationkey.fxml
rename to main/ui/src/main/resources/fxml/preferences_contribute.fxml
index 087d9da26..bfe91d0eb 100644
--- a/main/ui/src/main/resources/fxml/preferences_donationkey.fxml
+++ b/main/ui/src/main/resources/fxml/preferences_contribute.fxml
@@ -12,7 +12,7 @@
@@ -24,7 +24,7 @@
-
+
@@ -33,8 +33,8 @@
-
-
+
+
@@ -43,6 +43,6 @@
-
+
diff --git a/main/ui/src/main/resources/fxml/preferences_general.fxml b/main/ui/src/main/resources/fxml/preferences_general.fxml
index c167e392c..ea087b9e3 100644
--- a/main/ui/src/main/resources/fxml/preferences_general.fxml
+++ b/main/ui/src/main/resources/fxml/preferences_general.fxml
@@ -23,7 +23,7 @@
-
+
diff --git a/main/ui/src/main/resources/i18n/strings.properties b/main/ui/src/main/resources/i18n/strings.properties
index e02f04bb1..ad60cd0c5 100644
--- a/main/ui/src/main/resources/i18n/strings.properties
+++ b/main/ui/src/main/resources/i18n/strings.properties
@@ -175,11 +175,14 @@ preferences.updates.currentVersion=Current Version: %s
preferences.updates.autoUpdateCheck=Check for updates automatically
preferences.updates.checkNowBtn=Check Now
preferences.updates.updateAvailable=Update to version %s available.
-## Donation Key
-preferences.donationKey=Donation
-preferences.donationKey.registeredFor=Registered for %s
-preferences.donationKey.noDonationKey=No valid donation key found. It's like a license key but for awesome people using free software. ;-)
-preferences.donationKey.getDonationKey=Get a donation key
+## Contribution
+preferences.contribute=Support Us
+preferences.contribute.registeredFor=Supporter certificate registered for %s
+preferences.contribute.noCertificate=Support Cryptomator and receive a supporter certificate. It's like a license key but for awesome people using free software. ;-)
+preferences.contribute.getCertificate=Don't have one already? Learn how you can obtain it.
+preferences.contribute.promptText=Paste supporter certificate code here
+#<-- Add entries for donations and code/translation/documentation contribution -->
+
## About
preferences.about=About
diff --git a/main/ui/src/main/java/org/cryptomator/ui/preferences/SelectedPreferencesTab.java b/main/ui/src/main/java/org/cryptomator/ui/preferences/SelectedPreferencesTab.java
index a76f2ac1c..892d16a8c 100644
--- a/main/ui/src/main/java/org/cryptomator/ui/preferences/SelectedPreferencesTab.java
+++ b/main/ui/src/main/java/org/cryptomator/ui/preferences/SelectedPreferencesTab.java
@@ -22,9 +22,9 @@ public enum SelectedPreferencesTab {
UPDATES,
/**
* Show donation key tab
*/
- DONATION_KEY,
+ CONTRIBUTE,
/**
* Show about tab
@@ -22,9 +22,9 @@ public enum SelectedPreferencesTab {
UPDATES,
/**
- * Show donation key tab
+ * Show contribute tab
*/